# Generated by Django 4.2.23 on 2025-08-01 19:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0011_extend_industry_activites'),
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('milindustry', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='IndustryCharacter',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('eve_character', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='milindustry_industrycharacter', to='eveonline.evecharacter')),
            ],
        ),
        migrations.CreateModel(
            name='IndustryCharacterSkill',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('skill_level', models.PositiveSmallIntegerField()),
                ('industry_character', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='skills', to='milindustry.industrycharacter')),
                ('skill_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='industry_character_skills', to='eveuniverse.evetype')),
            ],
        ),
        migrations.AddConstraint(
            model_name='industrycharacterskill',
            constraint=models.UniqueConstraint(fields=('industry_character', 'skill_type'), name='unique_industry_character_skill'),
        ),
    ]
